@@ -85,7 +85,7 @@ def _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, PROFILES, DIRS,
                     except EnvironmentError, le:
                         print "note: couldn't read file named %s because %s" % (fname, le)
 
-                if md5h is None and len(fnames) > 1:
+                if md5h is None:
                     print "note: couldn't read any of these (same-inode) files: %s" % (fnames,)
                     break
 
